Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(574)

Unified Diff: ui/arc/notification/arc_notification_content_view.h

Issue 2906323002: Rename ArcCustomNotificationView to ArcNotificationContentView (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/arc/notification/arc_notification_content_view.h
diff --git a/ui/arc/notification/arc_custom_notification_view.h b/ui/arc/notification/arc_notification_content_view.h
similarity index 89%
rename from ui/arc/notification/arc_custom_notification_view.h
rename to ui/arc/notification/arc_notification_content_view.h
index ce2d65d90e4d0826cd23ffe547c3d0b055ed046d..6eb119e757c253729351e682b1c60cf5c599bc2f 100644
--- a/ui/arc/notification/arc_custom_notification_view.h
+++ b/ui/arc/notification/arc_notification_content_view.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef UI_ARC_NOTIFICATION_ARC_CUSTOM_NOTIFICATION_VIEW_H_
-#define UI_ARC_NOTIFICATION_ARC_CUSTOM_NOTIFICATION_VIEW_H_
+#ifndef UI_ARC_NOTIFICATION_ARC_NOTIFICATION_CONTENT_VIEW_H_
+#define UI_ARC_NOTIFICATION_ARC_NOTIFICATION_CONTENT_VIEW_H_
#include <memory>
#include <string>
@@ -37,10 +37,10 @@ class Widget;
namespace arc {
// ArcCustomNotificationView is a view to host NotificationSurface and show the
// content in itself. This is implemented as a child of ArcNotificationView.
// TODO(yoshiki): Rename this class to ArcNotificationContentsView.
hidehiko 2017/05/31 03:48:38 nit: please remove TODO.
yoshiki 2017/05/31 09:18:29 Good catch. Done.
-class ArcCustomNotificationView
+class ArcNotificationContentView
: public views::NativeViewHost,
public views::ButtonListener,
public aura::WindowObserver,
@@ -48,8 +48,8 @@ class ArcCustomNotificationView
public ArcNotificationSurfaceManager::Observer,
public gfx::AnimationDelegate {
public:
- explicit ArcCustomNotificationView(ArcNotificationItem* item);
- ~ArcCustomNotificationView() override;
+ explicit ArcNotificationContentView(ArcNotificationItem* item);
+ ~ArcNotificationContentView() override;
std::unique_ptr<ArcNotificationContentViewDelegate>
CreateContentViewDelegate();
@@ -65,12 +65,12 @@ class ArcCustomNotificationView
// requires size of this class.
class ControlButton : public message_center::PaddedButton {
public:
- explicit ControlButton(ArcCustomNotificationView* owner);
+ explicit ControlButton(ArcNotificationContentView* owner);
void OnFocus() override;
void OnBlur() override;
private:
- ArcCustomNotificationView* const owner_;
+ ArcNotificationContentView* const owner_;
DISALLOW_COPY_AND_ASSIGN(ControlButton);
};
@@ -154,9 +154,9 @@ class ArcCustomNotificationView
std::unique_ptr<gfx::LinearAnimation> control_button_color_animation_;
- DISALLOW_COPY_AND_ASSIGN(ArcCustomNotificationView);
+ DISALLOW_COPY_AND_ASSIGN(ArcNotificationContentView);
};
} // namespace arc
-#endif // UI_ARC_NOTIFICATION_ARC_CUSTOM_NOTIFICATION_VIEW_H_
+#endif // UI_ARC_NOTIFICATION_ARC_NOTIFICATION_CONTENT_VIEW_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -37,10 +37,10 @@ class Widget;
namespace arc {
-// ArcCustomNotificationView is a view to host NotificationSurface and show the
+// ArcNotificationContentView is a view to host NotificationSurface and show the
// content in itself. This is implemented as a child of ArcNotificationView.
// TODO(yoshiki): Rename this class to ArcNotificationContentsView.